# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional

import httpx

from ..._types import Body, Query, Headers, NoneType, NotGiven, SequenceNotStr, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.papers import private_create_params, private_update_metadata_params
from ...types.papers.private_create_response import PrivateCreateResponse

__all__ = ["PrivateResource", "AsyncPrivateResource"]


class PrivateResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PrivateResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return PrivateResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PrivateResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return PrivateResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        content_type: str,
        file: str,
        filename: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PrivateCreateResponse:
        """
        Upload a private PDF paper

        Source file:
        `api-server/src/controllers/v2/papers/upload-private-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v2/papers/private",
            body=maybe_transform(
                {
                    "content_type": content_type,
                    "file": file,
                    "filename": filename,
                },
                private_create_params.PrivateCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PrivateCreateResponse,
        )

    def update_metadata(
        self,
        paper_id: str,
        *,
        abstract: str,
        authors: Iterable[private_update_metadata_params.Author],
        bibtex: Optional[str],
        categories: SequenceNotStr[str],
        publication_date: float,
        title: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update metadata for a private paper

        Source file:
        `api-server/src/controllers/v2/papers/update-private-paper.controller.ts`

        Args:
          paper_id: An Unresolved Paper ID (UUID, ArXiv ID, or Versioned ArXiv ID)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            f"/v2/papers/private/{paper_id}/metadata",
            body=maybe_transform(
                {
                    "abstract": abstract,
                    "authors": authors,
                    "bibtex": bibtex,
                    "categories": categories,
                    "publication_date": publication_date,
                    "title": title,
                },
                private_update_metadata_params.PrivateUpdateMetadataParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncPrivateResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPrivateResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPrivateResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPrivateResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncPrivateResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        content_type: str,
        file: str,
        filename: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PrivateCreateResponse:
        """
        Upload a private PDF paper

        Source file:
        `api-server/src/controllers/v2/papers/upload-private-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v2/papers/private",
            body=await async_maybe_transform(
                {
                    "content_type": content_type,
                    "file": file,
                    "filename": filename,
                },
                private_create_params.PrivateCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PrivateCreateResponse,
        )

    async def update_metadata(
        self,
        paper_id: str,
        *,
        abstract: str,
        authors: Iterable[private_update_metadata_params.Author],
        bibtex: Optional[str],
        categories: SequenceNotStr[str],
        publication_date: float,
        title: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update metadata for a private paper

        Source file:
        `api-server/src/controllers/v2/papers/update-private-paper.controller.ts`

        Args:
          paper_id: An Unresolved Paper ID (UUID, ArXiv ID, or Versioned ArXiv ID)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            f"/v2/papers/private/{paper_id}/metadata",
            body=await async_maybe_transform(
                {
                    "abstract": abstract,
                    "authors": authors,
                    "bibtex": bibtex,
                    "categories": categories,
                    "publication_date": publication_date,
                    "title": title,
                },
                private_update_metadata_params.PrivateUpdateMetadataParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class PrivateResourceWithRawResponse:
    def __init__(self, private: PrivateResource) -> None:
        self._private = private

        self.create = to_raw_response_wrapper(
            private.create,
        )
        self.update_metadata = to_raw_response_wrapper(
            private.update_metadata,
        )


class AsyncPrivateResourceWithRawResponse:
    def __init__(self, private: AsyncPrivateResource) -> None:
        self._private = private

        self.create = async_to_raw_response_wrapper(
            private.create,
        )
        self.update_metadata = async_to_raw_response_wrapper(
            private.update_metadata,
        )


class PrivateResourceWithStreamingResponse:
    def __init__(self, private: PrivateResource) -> None:
        self._private = private

        self.create = to_streamed_response_wrapper(
            private.create,
        )
        self.update_metadata = to_streamed_response_wrapper(
            private.update_metadata,
        )


class AsyncPrivateResourceWithStreamingResponse:
    def __init__(self, private: AsyncPrivateResource) -> None:
        self._private = private

        self.create = async_to_streamed_response_wrapper(
            private.create,
        )
        self.update_metadata = async_to_streamed_response_wrapper(
            private.update_metadata,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .lab_retrieve_response import LabRetrieveResponse as LabRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v4 import (
    V4Resource,
    AsyncV4Resource,
    V4ResourceWithRawResponse,
    AsyncV4ResourceWithRawResponse,
    V4ResourceWithStreamingResponse,
    AsyncV4ResourceWithStreamingResponse,
)
from .archive import (
    ArchiveResource,
    AsyncArchiveResource,
    ArchiveResourceWithRawResponse,
    AsyncArchiveResourceWithRawResponse,
    ArchiveResourceWithStreamingResponse,
    AsyncArchiveResourceWithStreamingResponse,
)

__all__ = [
    "ArchiveResource",
    "AsyncArchiveResource",
    "ArchiveResourceWithRawResponse",
    "AsyncArchiveResourceWithRawResponse",
    "ArchiveResourceWithStreamingResponse",
    "AsyncArchiveResourceWithStreamingResponse",
    "V4Resource",
    "AsyncV4Resource",
    "V4ResourceWithRawResponse",
    "AsyncV4ResourceWithRawResponse",
    "V4ResourceWithStreamingResponse",
    "AsyncV4ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["V3AddPapersParams"]


class V3AddPapersParams(TypedDict, total=False):
    paper_group_ids: Annotated[SequenceNotStr[str], PropertyInfo(alias="paperGroupIds")]

    universal_ids: Annotated[SequenceNotStr[str], PropertyInfo(alias="universalIds")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["VersionRequestAIOverviewResponse"]


class VersionRequestAIOverviewResponse(BaseModel):
    data: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["SitemapListOverviewsResponse", "Data", "DataPagination", "DataPaper"]


class DataPagination(BaseModel):
    total: float

    limit: Optional[float] = None

    page: Optional[float] = None


class DataPaper(BaseModel):
    id: str

    language: str

    universal_paper_id: str

    updated_at: str

    version_order: float


class Data(BaseModel):
    pagination: DataPagination

    papers: List[DataPaper]


class SitemapListOverviewsResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .email_get_response import EmailGetResponse as EmailGetResponse
from .email_update_params import EmailUpdateParams as EmailUpdateParams
from .email_update_response import EmailUpdateResponse as EmailUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["PaperAdminVoteResponse", "Data"]


class Data(BaseModel):
    success: bool


class PaperAdminVoteResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .seen import (
    SeenResource,
    AsyncSeenResource,
    SeenResourceWithRawResponse,
    AsyncSeenResourceWithRawResponse,
    SeenResourceWithStreamingResponse,
    AsyncSeenResourceWithStreamingResponse,
)

__all__ = [
    "SeenResource",
    "AsyncSeenResource",
    "SeenResourceWithRawResponse",
    "AsyncSeenResourceWithRawResponse",
    "SeenResourceWithStreamingResponse",
    "AsyncSeenResourceWithStreamingResponse",
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_get_top_papers_params import V1GetTopPapersParams as V1GetTopPapersParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["PaperViewCountProcessJobParams"]


class PaperViewCountProcessJobParams(TypedDict, total=False):
    paper_id: Required[Annotated[str, PropertyInfo(alias="paperId")]]
    """Paper ID to process view counts for"""

    publication_date: Required[Annotated[str, PropertyInfo(alias="publicationDate")]]
    """Publication date for age decay calculation"""

    like: bool
    """Whether to add noise to votes"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = [
    "ByUsernameGetProfilePageResponse",
    "Activity",
    "ActivityItem",
    "ActivityItemAnnotation",
    "ActivityItemAnnotationAnchorPosition",
    "ActivityItemAnnotationFocusPosition",
    "ActivityItemAnnotationHighlightRect",
    "ActivityItemAnnotationHighlightRectRect",
    "ActivityItemAuthor",
    "ActivityItemAuthorAvatar",
    "ActivityItemEndorsement",
    "ClaimedPaper",
    "Featured",
    "FeaturedUnionMember0",
    "FeaturedUnionMember0Data",
    "FeaturedUnionMember1",
    "FeaturedUnionMember1Data",
    "User",
    "UserAvatar",
    "UserSemanticScholar",
    "UserFeatured",
]


class ActivityItemAnnotationAnchorPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class ActivityItemAnnotationFocusPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class ActivityItemAnnotationHighlightRectRect(BaseModel):
    x1: float

    x2: float

    y1: float

    y2: float


class ActivityItemAnnotationHighlightRect(BaseModel):
    page_index: float = FieldInfo(alias="pageIndex")

    rects: List[ActivityItemAnnotationHighlightRectRect]


class ActivityItemAnnotation(BaseModel):
    anchor_position: ActivityItemAnnotationAnchorPosition = FieldInfo(alias="anchorPosition")

    focus_position: ActivityItemAnnotationFocusPosition = FieldInfo(alias="focusPosition")

    highlight_rects: List[ActivityItemAnnotationHighlightRect] = FieldInfo(alias="highlightRects")

    selected_text: str = FieldInfo(alias="selectedText")

    type: Literal["highlight"]

    color: Optional[str] = None


class ActivityItemAuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class ActivityItemAuthor(BaseModel):
    id: str

    avatar: Optional[List[ActivityItemAuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class ActivityItemEndorsement(BaseModel):
    id: str

    name: str


class ActivityItem(BaseModel):
    id: str

    annotation: Optional[ActivityItemAnnotation] = None

    author: ActivityItemAuthor

    body: Optional[str] = None

    date: str

    endorsements: List[ActivityItemEndorsement]

    has_downvoted: bool = FieldInfo(alias="hasDownvoted")

    has_flagged: bool = FieldInfo(alias="hasFlagged")

    has_upvoted: bool = FieldInfo(alias="hasUpvoted")

    is_author: bool = FieldInfo(alias="isAuthor")

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    paper_title: str = FieldInfo(alias="paperTitle")

    paper_version_id: str = FieldInfo(alias="paperVersionId")

    parent_comment_id: Optional[str] = FieldInfo(alias="parentCommentId", default=None)

    tag: str

    title: Optional[str] = None

    universal_id: str = FieldInfo(alias="universalId")

    upvotes: float

    was_edited: bool = FieldInfo(alias="wasEdited")


class Activity(BaseModel):
    date: str

    item: ActivityItem

    liked: float

    type: Literal["comment"]

    paper_likes: Optional[float] = FieldInfo(alias="paperLikes", default=None)

    paper_publication_date: Optional[str] = FieldInfo(alias="paperPublicationDate", default=None)

    paper_topics: Optional[List[str]] = FieldInfo(alias="paperTopics", default=None)


class ClaimedPaper(BaseModel):
    id: str

    abstract: str

    authors: List[str]

    citations: float

    google_citation_id: Optional[str] = None

    image_url: Optional[str] = FieldInfo(alias="imageURL", default=None)

    paper_id: str
    """A versionless universal paper ID (e.g. 1706.03762)"""

    public_total_votes: float

    publication_date: str

    title: str

    topics: List[str]


class FeaturedUnionMember0Data(BaseModel):
    id: str

    date: str

    link: Optional[str] = None

    organization: Optional[str] = None

    recording: Optional[str] = None

    speaker: Optional[str] = None

    title: str


class FeaturedUnionMember0(BaseModel):
    data: FeaturedUnionMember0Data

    type: Literal["video"]


class FeaturedUnionMember1Data(BaseModel):
    abstract: Optional[str] = None

    publication_date: str

    title: str

    universal_paper_id: str


class FeaturedUnionMember1(BaseModel):
    data: FeaturedUnionMember1Data

    type: Literal["paper"]


Featured: TypeAlias = Union[FeaturedUnionMember0, FeaturedUnionMember1]


class UserAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class UserSemanticScholar(BaseModel):
    id: str

    citation_count: Optional[float] = FieldInfo(alias="citationCount", default=None)

    external_ids: Optional[List[Optional[object]]] = FieldInfo(alias="externalIds", default=None)

    h_index: Optional[float] = FieldInfo(alias="hIndex", default=None)

    homepage: Optional[str] = None

    paper_count: Optional[float] = FieldInfo(alias="paperCount", default=None)


class UserFeatured(BaseModel):
    event_id: Optional[str] = FieldInfo(alias="eventId", default=None)

    paper_version_id: Optional[str] = FieldInfo(alias="paperVersionId", default=None)

    type: Literal["video", "paper"]


class User(BaseModel):
    id: str

    avatar: Optional[List[UserAvatar]] = None

    biography: Optional[str] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    email: str

    first_login: bool = FieldInfo(alias="firstLogin")

    follower_count: float = FieldInfo(alias="followerCount")

    following_count: float = FieldInfo(alias="followingCount")

    following_topics_count: float = FieldInfo(alias="followingTopicsCount")

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    location: Optional[str] = None

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    semantic_scholar: Optional[UserSemanticScholar] = FieldInfo(alias="semanticScholar", default=None)

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)

    featured: Optional[List[UserFeatured]] = None

    following_organizations: Optional[List[str]] = FieldInfo(alias="followingOrganizations", default=None)


class ByUsernameGetProfilePageResponse(BaseModel):
    activity: List[Activity]

    claimed_papers: List[ClaimedPaper] = FieldInfo(alias="claimedPapers")

    featured: List[Featured]

    user: User



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V2GetChatsParams"]


class V2GetChatsParams(TypedDict, total=False):
    folder: str

    paper_version: Annotated[str, PropertyInfo(alias="paperVersion")]

    variant: Literal["homepage", "paper", "folder"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "V1GetReportResponse",
    "V1GetReportResponseItem",
    "V1GetReportResponseItemUnionMember0",
    "V1GetReportResponseItemUnionMember1",
]


class V1GetReportResponseItemUnionMember0(BaseModel):
    status: Literal["claimed"]

    title: str

    universal_id: str = FieldInfo(alias="universalId")
    """A versionless universal paper ID (e.g. 1706.03762)"""


class V1GetReportResponseItemUnionMember1(BaseModel):
    google_citation_id: str = FieldInfo(alias="googleCitationId")

    status: Literal["error", "not-found"]

    title: str


V1GetReportResponseItem: TypeAlias = Union[V1GetReportResponseItemUnionMember0, V1GetReportResponseItemUnionMember1]

V1GetReportResponse: TypeAlias = List[V1GetReportResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3KickoffPaperCountriesParams"]


class V3KickoffPaperCountriesParams(TypedDict, total=False):
    batch: float
    """Number of papers to process in each batch"""

    max_papers: Annotated[float, PropertyInfo(alias="maxPapers")]
    """Maximum number of papers to process"""

    months: float
    """Only process papers at least this many months old"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EmailProcessCommentUpdateResponse", "Data"]


class Data(BaseModel):
    processed_user: str = FieldInfo(alias="processedUser")


class EmailProcessCommentUpdateResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["V3KickoffThumbnailsTrendingPapersResponse", "Data"]


class Data(BaseModel):
    message: str


class V3KickoffThumbnailsTrendingPapersResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal

import httpx

from .messages import (
    MessagesResource,
    AsyncMessagesResource,
    MessagesResourceWithRawResponse,
    AsyncMessagesResourceWithRawResponse,
    MessagesResourceWithStreamingResponse,
    AsyncMessagesResourceWithStreamingResponse,
)
from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._streaming import Stream, AsyncStream
from ...._base_client import make_request_options
from ....types.assistant import v2_chat_params, v2_edit_chat_params, v2_get_chats_params, v2_get_url_metadata_params
from ....types.assistant.v2_get_chats_response import V2GetChatsResponse
from ....types.assistant.v2_get_url_metadata_response import V2GetURLMetadataResponse

__all__ = ["V2Resource", "AsyncV2Resource"]


class V2Resource(SyncAPIResource):
    @cached_property
    def messages(self) -> MessagesResource:
        return MessagesResource(self._client)

    @cached_property
    def with_raw_response(self) -> V2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V2ResourceWithStreamingResponse(self)

    def chat(
        self,
        *,
        files: Iterable[v2_chat_params.File],
        llm_chat_id: Optional[str],
        message: str,
        paper_version_id: Optional[str],
        parent_message_id: Optional[str],
        selection_page_range: Optional[Iterable[int]],
        thinking: bool,
        web_search: Literal["off", "full"],
        assistant_variant: Literal["homepage", "paper", "folder", "landing", "folder-add-papers"] | Omit = omit,
        folder_add_papers: bool | Omit = omit,
        folder_id: str | Omit = omit,
        model: Literal[
            "gemini-2.5-flash",
            "gemini-2.5-pro",
            "gemini-3-flash",
            "gemini-3-pro",
            "gemini-3.1-pro",
            "claude-4.5-sonnet",
            "claude-4.6-sonnet",
            "grok-4",
            "qwen-3",
            "qwen-3-next",
            "qwen-3.5",
            "gpt-5",
            "gpt-5.2",
            "gpt-5.4",
            "gpt-oss-120b",
            "llama-4-maverick",
            "kimi-k2",
            "kimi-k2.5",
            "glm-5",
            "minimax-m2.5",
            "aurelle-1",
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Stream[object]:
        """
        Send a message to the AI assistant and receive streaming responses

        Source file: `api-server/src/controllers/assistant/v2/chat.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return self._post(
            "/assistant/v2/chat",
            body=maybe_transform(
                {
                    "files": files,
                    "llm_chat_id": llm_chat_id,
                    "message": message,
                    "paper_version_id": paper_version_id,
                    "parent_message_id": parent_message_id,
                    "selection_page_range": selection_page_range,
                    "thinking": thinking,
                    "web_search": web_search,
                    "assistant_variant": assistant_variant,
                    "folder_add_papers": folder_add_papers,
                    "folder_id": folder_id,
                    "model": model,
                },
                v2_chat_params.V2ChatParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
            stream=True,
            stream_cls=Stream[object],
        )

    def delete_chat(
        self,
        llm_chat: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete an llm chat by id

        Source file: `api-server/src/controllers/assistant/v2/delete-chat.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not llm_chat:
            raise ValueError(f"Expected a non-empty value for `llm_chat` but received {llm_chat!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/assistant/v2/{llm_chat}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def edit_chat(
        self,
        llm_chat: str,
        *,
        title: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Updates properties on an LlmChat.

        Currently only supports title

        Source file: `api-server/src/controllers/assistant/v2/edit-chat.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not llm_chat:
            raise ValueError(f"Expected a non-empty value for `llm_chat` but received {llm_chat!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            f"/assistant/v2/{llm_chat}",
            body=maybe_transform({"title": title}, v2_edit_chat_params.V2EditChatParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get_chats(
        self,
        *,
        folder: str | Omit = omit,
        paper_version: str | Omit = omit,
        variant: Literal["homepage", "paper", "folder"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2GetChatsResponse:
        """
        Get llm chats for this user, filtered by variant, and optionally by paper
        version

        Source file: `api-server/src/controllers/assistant/v2/get-chats.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/assistant/v2",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "folder": folder,
                        "paper_version": paper_version,
                        "variant": variant,
                    },
                    v2_get_chats_params.V2GetChatsParams,
                ),
            ),
            cast_to=V2GetChatsResponse,
        )

    def get_url_metadata(
        self,
        *,
        url: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2GetURLMetadataResponse:
        """
        Fetch metadata (title and favicon) from a given URL

        Source file:
        `api-server/src/controllers/assistant/v2/get-url-metadata.controller.ts`

        Args:
          url: The URL to fetch metadata from

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/assistant/v2/url-metadata",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"url": url}, v2_get_url_metadata_params.V2GetURLMetadataParams),
            ),
            cast_to=V2GetURLMetadataResponse,
        )


class AsyncV2Resource(AsyncAPIResource):
    @cached_property
    def messages(self) -> AsyncMessagesResource:
        return AsyncMessagesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV2ResourceWithStreamingResponse(self)

    async def chat(
        self,
        *,
        files: Iterable[v2_chat_params.File],
        llm_chat_id: Optional[str],
        message: str,
        paper_version_id: Optional[str],
        parent_message_id: Optional[str],
        selection_page_range: Optional[Iterable[int]],
        thinking: bool,
        web_search: Literal["off", "full"],
        assistant_variant: Literal["homepage", "paper", "folder", "landing", "folder-add-papers"] | Omit = omit,
        folder_add_papers: bool | Omit = omit,
        folder_id: str | Omit = omit,
        model: Literal[
            "gemini-2.5-flash",
            "gemini-2.5-pro",
            "gemini-3-flash",
            "gemini-3-pro",
            "gemini-3.1-pro",
            "claude-4.5-sonnet",
            "claude-4.6-sonnet",
            "grok-4",
            "qwen-3",
            "qwen-3-next",
            "qwen-3.5",
            "gpt-5",
            "gpt-5.2",
            "gpt-5.4",
            "gpt-oss-120b",
            "llama-4-maverick",
            "kimi-k2",
            "kimi-k2.5",
            "glm-5",
            "minimax-m2.5",
            "aurelle-1",
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncStream[object]:
        """
        Send a message to the AI assistant and receive streaming responses

        Source file: `api-server/src/controllers/assistant/v2/chat.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "text/event-stream", **(extra_headers or {})}
        return await self._post(
            "/assistant/v2/chat",
            body=await async_maybe_transform(
                {
                    "files": files,
                    "llm_chat_id": llm_chat_id,
                    "message": message,
                    "paper_version_id": paper_version_id,
                    "parent_message_id": parent_message_id,
                    "selection_page_range": selection_page_range,
                    "thinking": thinking,
                    "web_search": web_search,
                    "assistant_variant": assistant_variant,
                    "folder_add_papers": folder_add_papers,
                    "folder_id": folder_id,
                    "model": model,
                },
                v2_chat_params.V2ChatParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
            stream=True,
            stream_cls=AsyncStream[object],
        )

    async def delete_chat(
        self,
        llm_chat: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete an llm chat by id

        Source file: `api-server/src/controllers/assistant/v2/delete-chat.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not llm_chat:
            raise ValueError(f"Expected a non-empty value for `llm_chat` but received {llm_chat!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/assistant/v2/{llm_chat}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def edit_chat(
        self,
        llm_chat: str,
        *,
        title: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """Updates properties on an LlmChat.

        Currently only supports title

        Source file: `api-server/src/controllers/assistant/v2/edit-chat.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not llm_chat:
            raise ValueError(f"Expected a non-empty value for `llm_chat` but received {llm_chat!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            f"/assistant/v2/{llm_chat}",
            body=await async_maybe_transform({"title": title}, v2_edit_chat_params.V2EditChatParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_chats(
        self,
        *,
        folder: str | Omit = omit,
        paper_version: str | Omit = omit,
        variant: Literal["homepage", "paper", "folder"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2GetChatsResponse:
        """
        Get llm chats for this user, filtered by variant, and optionally by paper
        version

        Source file: `api-server/src/controllers/assistant/v2/get-chats.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/assistant/v2",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "folder": folder,
                        "paper_version": paper_version,
                        "variant": variant,
                    },
                    v2_get_chats_params.V2GetChatsParams,
                ),
            ),
            cast_to=V2GetChatsResponse,
        )

    async def get_url_metadata(
        self,
        *,
        url: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V2GetURLMetadataResponse:
        """
        Fetch metadata (title and favicon) from a given URL

        Source file:
        `api-server/src/controllers/assistant/v2/get-url-metadata.controller.ts`

        Args:
          url: The URL to fetch metadata from

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/assistant/v2/url-metadata",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"url": url}, v2_get_url_metadata_params.V2GetURLMetadataParams),
            ),
            cast_to=V2GetURLMetadataResponse,
        )


class V2ResourceWithRawResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

        self.chat = to_raw_response_wrapper(
            v2.chat,
        )
        self.delete_chat = to_raw_response_wrapper(
            v2.delete_chat,
        )
        self.edit_chat = to_raw_response_wrapper(
            v2.edit_chat,
        )
        self.get_chats = to_raw_response_wrapper(
            v2.get_chats,
        )
        self.get_url_metadata = to_raw_response_wrapper(
            v2.get_url_metadata,
        )

    @cached_property
    def messages(self) -> MessagesResourceWithRawResponse:
        return MessagesResourceWithRawResponse(self._v2.messages)


class AsyncV2ResourceWithRawResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

        self.chat = async_to_raw_response_wrapper(
            v2.chat,
        )
        self.delete_chat = async_to_raw_response_wrapper(
            v2.delete_chat,
        )
        self.edit_chat = async_to_raw_response_wrapper(
            v2.edit_chat,
        )
        self.get_chats = async_to_raw_response_wrapper(
            v2.get_chats,
        )
        self.get_url_metadata = async_to_raw_response_wrapper(
            v2.get_url_metadata,
        )

    @cached_property
    def messages(self) -> AsyncMessagesResourceWithRawResponse:
        return AsyncMessagesResourceWithRawResponse(self._v2.messages)


class V2ResourceWithStreamingResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

        self.chat = to_streamed_response_wrapper(
            v2.chat,
        )
        self.delete_chat = to_streamed_response_wrapper(
            v2.delete_chat,
        )
        self.edit_chat = to_streamed_response_wrapper(
            v2.edit_chat,
        )
        self.get_chats = to_streamed_response_wrapper(
            v2.get_chats,
        )
        self.get_url_metadata = to_streamed_response_wrapper(
            v2.get_url_metadata,
        )

    @cached_property
    def messages(self) -> MessagesResourceWithStreamingResponse:
        return MessagesResourceWithStreamingResponse(self._v2.messages)


class AsyncV2ResourceWithStreamingResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

        self.chat = async_to_streamed_response_wrapper(
            v2.chat,
        )
        self.delete_chat = async_to_streamed_response_wrapper(
            v2.delete_chat,
        )
        self.edit_chat = async_to_streamed_response_wrapper(
            v2.edit_chat,
        )
        self.get_chats = async_to_streamed_response_wrapper(
            v2.get_chats,
        )
        self.get_url_metadata = async_to_streamed_response_wrapper(
            v2.get_url_metadata,
        )

    @cached_property
    def messages(self) -> AsyncMessagesResourceWithStreamingResponse:
        return AsyncMessagesResourceWithStreamingResponse(self._v2.messages)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3RetrievePapersByCountryResponse", "V3RetrievePapersByCountryResponseItem"]


class V3RetrievePapersByCountryResponseItem(BaseModel):
    abstract: str

    citations_count: float = FieldInfo(alias="citationsCount")

    comments_count: float = FieldInfo(alias="commentsCount")

    countries: List[str]

    first_publication_date: str = FieldInfo(alias="firstPublicationDate")

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    publication_date: str = FieldInfo(alias="publicationDate")

    public_total_votes: float = FieldInfo(alias="publicTotalVotes")

    title: str

    total_votes: float = FieldInfo(alias="totalVotes")

    universal_id: str = FieldInfo(alias="universalId")

    visits_all: float = FieldInfo(alias="visitsAll")


V3RetrievePapersByCountryResponse: TypeAlias = List[V3RetrievePapersByCountryResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["ModeratorToggleFlagsResponse"]


class ModeratorToggleFlagsResponse(BaseModel):
    addressed: bool

    closed: bool

    flag_addressed: bool = FieldInfo(alias="flagAddressed")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["XMentionUpdateParams"]


class XMentionUpdateParams(TypedDict, total=False):
    dry_run: Annotated[bool, PropertyInfo(alias="dryRun")]
    """If true, only logs results without saving to database"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import Literal, TypeAlias

from ..._models import BaseModel

__all__ = ["V1GetDailyConversationsResponse", "V1GetDailyConversationsResponseItem"]


class V1GetDailyConversationsResponseItem(BaseModel):
    count: float

    date: str

    variant: Literal["homepage", "paper", "folder"]


V1GetDailyConversationsResponse: TypeAlias = List[V1GetDailyConversationsResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.users.v3.semantic_scholar_link_response import SemanticScholarLinkResponse
from ....types.users.v3.semantic_scholar_scrape_response import SemanticScholarScrapeResponse

__all__ = ["SemanticScholarResource", "AsyncSemanticScholarResource"]


class SemanticScholarResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SemanticScholarResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return SemanticScholarResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SemanticScholarResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return SemanticScholarResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    def link(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SemanticScholarLinkResponse:
        """
        Link a user's account to a Semantic Scholar profile based on claimed papers

        Source file:
        `api-server/src/controllers/users/v3/link-semantic-scholar.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._post(
            f"/users/v3/{id}/semantic-scholar/link",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SemanticScholarLinkResponse,
        )

    @typing_extensions.deprecated("deprecated")
    def scrape(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SemanticScholarScrapeResponse:
        """
        Refresh Semantic Scholar data for a linked user

        Source file:
        `api-server/src/controllers/users/v3/scrape-semantic-scholar.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._post(
            f"/users/v3/{id}/semantic-scholar/scrape",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SemanticScholarScrapeResponse,
        )


class AsyncSemanticScholarResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSemanticScholarResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSemanticScholarResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSemanticScholarResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncSemanticScholarResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    async def link(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SemanticScholarLinkResponse:
        """
        Link a user's account to a Semantic Scholar profile based on claimed papers

        Source file:
        `api-server/src/controllers/users/v3/link-semantic-scholar.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._post(
            f"/users/v3/{id}/semantic-scholar/link",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SemanticScholarLinkResponse,
        )

    @typing_extensions.deprecated("deprecated")
    async def scrape(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SemanticScholarScrapeResponse:
        """
        Refresh Semantic Scholar data for a linked user

        Source file:
        `api-server/src/controllers/users/v3/scrape-semantic-scholar.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._post(
            f"/users/v3/{id}/semantic-scholar/scrape",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SemanticScholarScrapeResponse,
        )


class SemanticScholarResourceWithRawResponse:
    def __init__(self, semantic_scholar: SemanticScholarResource) -> None:
        self._semantic_scholar = semantic_scholar

        self.link = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                semantic_scholar.link,  # pyright: ignore[reportDeprecated],
            )
        )
        self.scrape = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                semantic_scholar.scrape,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncSemanticScholarResourceWithRawResponse:
    def __init__(self, semantic_scholar: AsyncSemanticScholarResource) -> None:
        self._semantic_scholar = semantic_scholar

        self.link = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                semantic_scholar.link,  # pyright: ignore[reportDeprecated],
            )
        )
        self.scrape = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                semantic_scholar.scrape,  # pyright: ignore[reportDeprecated],
            )
        )


class SemanticScholarResourceWithStreamingResponse:
    def __init__(self, semantic_scholar: SemanticScholarResource) -> None:
        self._semantic_scholar = semantic_scholar

        self.link = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                semantic_scholar.link,  # pyright: ignore[reportDeprecated],
            )
        )
        self.scrape = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                semantic_scholar.scrape,  # pyright: ignore[reportDeprecated],
            )
        )


class AsyncSemanticScholarResourceWithStreamingResponse:
    def __init__(self, semantic_scholar: AsyncSemanticScholarResource) -> None:
        self._semantic_scholar = semantic_scholar

        self.link = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                semantic_scholar.link,  # pyright: ignore[reportDeprecated],
            )
        )
        self.scrape = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                semantic_scholar.scrape,  # pyright: ignore[reportDeprecated],
            )
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.notifications import V4ListNotificationsResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV4:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_notifications(self, client: AlphaxivCat) -> None:
        v4 = client.notifications.v4.list_notifications()
        assert_matches_type(V4ListNotificationsResponse, v4, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list_notifications(self, client: AlphaxivCat) -> None:
        response = client.notifications.v4.with_raw_response.list_notifications()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v4 = response.parse()
        assert_matches_type(V4ListNotificationsResponse, v4, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list_notifications(self, client: AlphaxivCat) -> None:
        with client.notifications.v4.with_streaming_response.list_notifications() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v4 = response.parse()
            assert_matches_type(V4ListNotificationsResponse, v4, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_subscribe(self, client: AlphaxivCat) -> None:
        v4 = client.notifications.v4.subscribe(
            subscription={
                "endpoint": "https://example.com",
                "keys": {
                    "auth": "auth",
                    "p256dh": "p256dh",
                },
            },
        )
        assert v4 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_subscribe(self, client: AlphaxivCat) -> None:
        response = client.notifications.v4.with_raw_response.subscribe(
            subscription={
                "endpoint": "https://example.com",
                "keys": {
                    "auth": "auth",
                    "p256dh": "p256dh",
                },
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v4 = response.parse()
        assert v4 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_subscribe(self, client: AlphaxivCat) -> None:
        with client.notifications.v4.with_streaming_response.subscribe(
            subscription={
                "endpoint": "https://example.com",
                "keys": {
                    "auth": "auth",
                    "p256dh": "p256dh",
                },
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v4 = response.parse()
            assert v4 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_unsubscribe(self, client: AlphaxivCat) -> None:
        v4 = client.notifications.v4.unsubscribe(
            endpoint="https://example.com",
        )
        assert v4 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_unsubscribe(self, client: AlphaxivCat) -> None:
        response = client.notifications.v4.with_raw_response.unsubscribe(
            endpoint="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v4 = response.parse()
        assert v4 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_unsubscribe(self, client: AlphaxivCat) -> None:
        with client.notifications.v4.with_streaming_response.unsubscribe(
            endpoint="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v4 = response.parse()
            assert v4 is None

        assert cast(Any, response.is_closed) is True


class TestAsyncV4:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_notifications(self, async_client: AsyncAlphaxivCat) -> None:
        v4 = await async_client.notifications.v4.list_notifications()
        assert_matches_type(V4ListNotificationsResponse, v4, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list_notifications(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.notifications.v4.with_raw_response.list_notifications()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v4 = await response.parse()
        assert_matches_type(V4ListNotificationsResponse, v4, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list_notifications(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.notifications.v4.with_streaming_response.list_notifications() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v4 = await response.parse()
            assert_matches_type(V4ListNotificationsResponse, v4, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_subscribe(self, async_client: AsyncAlphaxivCat) -> None:
        v4 = await async_client.notifications.v4.subscribe(
            subscription={
                "endpoint": "https://example.com",
                "keys": {
                    "auth": "auth",
                    "p256dh": "p256dh",
                },
            },
        )
        assert v4 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_subscribe(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.notifications.v4.with_raw_response.subscribe(
            subscription={
                "endpoint": "https://example.com",
                "keys": {
                    "auth": "auth",
                    "p256dh": "p256dh",
                },
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v4 = await response.parse()
        assert v4 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_subscribe(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.notifications.v4.with_streaming_response.subscribe(
            subscription={
                "endpoint": "https://example.com",
                "keys": {
                    "auth": "auth",
                    "p256dh": "p256dh",
                },
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v4 = await response.parse()
            assert v4 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_unsubscribe(self, async_client: AsyncAlphaxivCat) -> None:
        v4 = await async_client.notifications.v4.unsubscribe(
            endpoint="https://example.com",
        )
        assert v4 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_unsubscribe(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.notifications.v4.with_raw_response.unsubscribe(
            endpoint="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v4 = await response.parse()
        assert v4 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_unsubscribe(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.notifications.v4.with_streaming_response.unsubscribe(
            endpoint="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v4 = await response.parse()
            assert v4 is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["PaperToggleFollowResponse", "Data"]


class Data(BaseModel):
    paper_group_id: str = FieldInfo(alias="paperGroupId")


class PaperToggleFollowResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .paper import (
    PaperResource,
    AsyncPaperResource,
    PaperResourceWithRawResponse,
    AsyncPaperResourceWithRawResponse,
    PaperResourceWithStreamingResponse,
    AsyncPaperResourceWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["V2Resource", "AsyncV2Resource"]


class V2Resource(SyncAPIResource):
    @cached_property
    def paper(self) -> PaperResource:
        return PaperResource(self._client)

    @cached_property
    def with_raw_response(self) -> V2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V2ResourceWithStreamingResponse(self)


class AsyncV2Resource(AsyncAPIResource):
    @cached_property
    def paper(self) -> AsyncPaperResource:
        return AsyncPaperResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV2ResourceWithStreamingResponse(self)


class V2ResourceWithRawResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

    @cached_property
    def paper(self) -> PaperResourceWithRawResponse:
        return PaperResourceWithRawResponse(self._v2.paper)


class AsyncV2ResourceWithRawResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

    @cached_property
    def paper(self) -> AsyncPaperResourceWithRawResponse:
        return AsyncPaperResourceWithRawResponse(self._v2.paper)


class V2ResourceWithStreamingResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

    @cached_property
    def paper(self) -> PaperResourceWithStreamingResponse:
        return PaperResourceWithStreamingResponse(self._v2.paper)


class AsyncV2ResourceWithStreamingResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

    @cached_property
    def paper(self) -> AsyncPaperResourceWithStreamingResponse:
        return AsyncPaperResourceWithStreamingResponse(self._v2.paper)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from .assistant import (
    AssistantResource,
    AsyncAssistantResource,
    AssistantResourceWithRawResponse,
    AsyncAssistantResourceWithRawResponse,
    AssistantResourceWithStreamingResponse,
    AsyncAssistantResourceWithStreamingResponse,
)

__all__ = [
    "V2Resource",
    "AsyncV2Resource",
    "V2ResourceWithRawResponse",
    "AsyncV2ResourceWithRawResponse",
    "V2ResourceWithStreamingResponse",
    "AsyncV2ResourceWithStreamingResponse",
    "AssistantResource",
    "AsyncAssistantResource",
    "AssistantResourceWithRawResponse",
    "AsyncAssistantResourceWithRawResponse",
    "AssistantResourceWithStreamingResponse",
    "AsyncAssistantResourceWithStreamingResponse",
]



from __future__ import annotations

import datetime
from typing import Union

import pydantic

from alphaxiv_cat import _compat
from alphaxiv_cat._utils._json import openapi_dumps


class TestOpenapiDumps:
    def test_basic(self) -> None:
        data = {"key": "value", "number": 42}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"key":"value","number":42}'

    def test_datetime_serialization(self) -> None:
        dt = datetime.datetime(2023, 1, 1, 12, 0, 0)
        data = {"datetime": dt}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"datetime":"2023-01-01T12:00:00"}'

    def test_pydantic_model_serialization(self) -> None:
        class User(pydantic.BaseModel):
            first_name: str
            last_name: str
            age: int

        model_instance = User(first_name="John", last_name="Kramer", age=83)
        data = {"model": model_instance}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"model":{"first_name":"John","last_name":"Kramer","age":83}}'

    def test_pydantic_model_with_default_values(self) -> None:
        class User(pydantic.BaseModel):
            name: str
            role: str = "user"
            active: bool = True
            score: int = 0

        model_instance = User(name="Alice")
        data = {"model": model_instance}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"model":{"name":"Alice"}}'

    def test_pydantic_model_with_default_values_overridden(self) -> None:
        class User(pydantic.BaseModel):
            name: str
            role: str = "user"
            active: bool = True

        model_instance = User(name="Bob", role="admin", active=False)
        data = {"model": model_instance}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"model":{"name":"Bob","role":"admin","active":false}}'

    def test_pydantic_model_with_alias(self) -> None:
        class User(pydantic.BaseModel):
            first_name: str = pydantic.Field(alias="firstName")
            last_name: str = pydantic.Field(alias="lastName")

        model_instance = User(firstName="John", lastName="Doe")
        data = {"model": model_instance}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"model":{"firstName":"John","lastName":"Doe"}}'

    def test_pydantic_model_with_alias_and_default(self) -> None:
        class User(pydantic.BaseModel):
            user_name: str = pydantic.Field(alias="userName")
            user_role: str = pydantic.Field(default="member", alias="userRole")
            is_active: bool = pydantic.Field(default=True, alias="isActive")

        model_instance = User(userName="charlie")
        data = {"model": model_instance}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"model":{"userName":"charlie"}}'

        model_with_overrides = User(userName="diana", userRole="admin", isActive=False)
        data = {"model": model_with_overrides}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"model":{"userName":"diana","userRole":"admin","isActive":false}}'

    def test_pydantic_model_with_nested_models_and_defaults(self) -> None:
        class Address(pydantic.BaseModel):
            street: str
            city: str = "Unknown"

        class User(pydantic.BaseModel):
            name: str
            address: Address
            verified: bool = False

        if _compat.PYDANTIC_V1:
            # to handle forward references in Pydantic v1
            User.update_forward_refs(**locals())  # type: ignore[reportDeprecated]

        address = Address(street="123 Main St")
        user = User(name="Diana", address=address)
        data = {"user": user}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"user":{"name":"Diana","address":{"street":"123 Main St"}}}'

        address_with_city = Address(street="456 Oak Ave", city="Boston")
        user_verified = User(name="Eve", address=address_with_city, verified=True)
        data = {"user": user_verified}
        json_bytes = openapi_dumps(data)
        assert (
            json_bytes == b'{"user":{"name":"Eve","address":{"street":"456 Oak Ave","city":"Boston"},"verified":true}}'
        )

    def test_pydantic_model_with_optional_fields(self) -> None:
        class User(pydantic.BaseModel):
            name: str
            email: Union[str, None]
            phone: Union[str, None]

        model_with_none = User(name="Eve", email=None, phone=None)
        data = {"model": model_with_none}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"model":{"name":"Eve","email":null,"phone":null}}'

        model_with_values = User(name="Frank", email="frank@example.com", phone=None)
        data = {"model": model_with_values}
        json_bytes = openapi_dumps(data)
        assert json_bytes == b'{"model":{"name":"Frank","email":"frank@example.com","phone":null}}'



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["SharedCopyResponse"]


class SharedCopyResponse(BaseModel):
    copied_count: float = FieldInfo(alias="copiedCount")

    copied_folders: float = FieldInfo(alias="copiedFolders")

    folder_id: str = FieldInfo(alias="folderId")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.papers import metadata_retrieve_latest_metadata_params, metadata_retrieve_version_metadata_params
from ...types.papers.metadata_retrieve_latest_metadata_response import MetadataRetrieveLatestMetadataResponse
from ...types.papers.metadata_retrieve_version_metadata_response import MetadataRetrieveVersionMetadataResponse

__all__ = ["MetadataResource", "AsyncMetadataResource"]


class MetadataResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MetadataResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return MetadataResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MetadataResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return MetadataResourceWithStreamingResponse(self)

    def retrieve_latest_metadata(
        self,
        upid: str,
        *,
        prevent_tracking: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MetadataRetrieveLatestMetadataResponse:
        """
        Get metadata for latest paper version (deprecated, used by browser extension)

        Source file:
        `api-server/src/controllers/v2/papers/get-paper-metadata-latest.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        return self._get(
            f"/v2/papers/{upid}/metadata",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"prevent_tracking": prevent_tracking},
                    metadata_retrieve_latest_metadata_params.MetadataRetrieveLatestMetadataParams,
                ),
            ),
            cast_to=MetadataRetrieveLatestMetadataResponse,
        )

    def retrieve_version_metadata(
        self,
        version_order: str,
        *,
        upid: str,
        prevent_tracking: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MetadataRetrieveVersionMetadataResponse:
        """
        Get metadata for a specific paper version (deprecated, used by browser
        extension)

        Source file:
        `api-server/src/controllers/v2/papers/get-paper-metadata.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        if not version_order:
            raise ValueError(f"Expected a non-empty value for `version_order` but received {version_order!r}")
        return self._get(
            f"/v2/papers/{upid}/metadata/versions/{version_order}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"prevent_tracking": prevent_tracking},
                    metadata_retrieve_version_metadata_params.MetadataRetrieveVersionMetadataParams,
                ),
            ),
            cast_to=MetadataRetrieveVersionMetadataResponse,
        )


class AsyncMetadataResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMetadataResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMetadataResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMetadataResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncMetadataResourceWithStreamingResponse(self)

    async def retrieve_latest_metadata(
        self,
        upid: str,
        *,
        prevent_tracking: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MetadataRetrieveLatestMetadataResponse:
        """
        Get metadata for latest paper version (deprecated, used by browser extension)

        Source file:
        `api-server/src/controllers/v2/papers/get-paper-metadata-latest.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        return await self._get(
            f"/v2/papers/{upid}/metadata",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"prevent_tracking": prevent_tracking},
                    metadata_retrieve_latest_metadata_params.MetadataRetrieveLatestMetadataParams,
                ),
            ),
            cast_to=MetadataRetrieveLatestMetadataResponse,
        )

    async def retrieve_version_metadata(
        self,
        version_order: str,
        *,
        upid: str,
        prevent_tracking: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MetadataRetrieveVersionMetadataResponse:
        """
        Get metadata for a specific paper version (deprecated, used by browser
        extension)

        Source file:
        `api-server/src/controllers/v2/papers/get-paper-metadata.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        if not version_order:
            raise ValueError(f"Expected a non-empty value for `version_order` but received {version_order!r}")
        return await self._get(
            f"/v2/papers/{upid}/metadata/versions/{version_order}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"prevent_tracking": prevent_tracking},
                    metadata_retrieve_version_metadata_params.MetadataRetrieveVersionMetadataParams,
                ),
            ),
            cast_to=MetadataRetrieveVersionMetadataResponse,
        )


class MetadataResourceWithRawResponse:
    def __init__(self, metadata: MetadataResource) -> None:
        self._metadata = metadata

        self.retrieve_latest_metadata = to_raw_response_wrapper(
            metadata.retrieve_latest_metadata,
        )
        self.retrieve_version_metadata = to_raw_response_wrapper(
            metadata.retrieve_version_metadata,
        )


class AsyncMetadataResourceWithRawResponse:
    def __init__(self, metadata: AsyncMetadataResource) -> None:
        self._metadata = metadata

        self.retrieve_latest_metadata = async_to_raw_response_wrapper(
            metadata.retrieve_latest_metadata,
        )
        self.retrieve_version_metadata = async_to_raw_response_wrapper(
            metadata.retrieve_version_metadata,
        )


class MetadataResourceWithStreamingResponse:
    def __init__(self, metadata: MetadataResource) -> None:
        self._metadata = metadata

        self.retrieve_latest_metadata = to_streamed_response_wrapper(
            metadata.retrieve_latest_metadata,
        )
        self.retrieve_version_metadata = to_streamed_response_wrapper(
            metadata.retrieve_version_metadata,
        )


class AsyncMetadataResourceWithStreamingResponse:
    def __init__(self, metadata: AsyncMetadataResource) -> None:
        self._metadata = metadata

        self.retrieve_latest_metadata = async_to_streamed_response_wrapper(
            metadata.retrieve_latest_metadata,
        )
        self.retrieve_version_metadata = async_to_streamed_response_wrapper(
            metadata.retrieve_version_metadata,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .email_send_weekly_digest_params import EmailSendWeeklyDigestParams as EmailSendWeeklyDigestParams
from .email_send_monthly_digest_params import EmailSendMonthlyDigestParams as EmailSendMonthlyDigestParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.users.preferences import email_update_params
from ....types.users.preferences.email_get_response import EmailGetResponse
from ....types.users.preferences.email_update_response import EmailUpdateResponse

__all__ = ["EmailResource", "AsyncEmailResource"]


class EmailResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EmailResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return EmailResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EmailResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return EmailResourceWithStreamingResponse(self)

    def update(
        self,
        *,
        direct_notifications: bool | Omit = omit,
        relevant_activity: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailUpdateResponse:
        """
        Update email preferences for the authenticated user

        Source file:
        `api-server/src/controllers/v2/users/update-email-preferences.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._put(
            "/v2/users/preferences/email",
            body=maybe_transform(
                {
                    "direct_notifications": direct_notifications,
                    "relevant_activity": relevant_activity,
                },
                email_update_params.EmailUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailUpdateResponse,
        )

    def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailGetResponse:
        """
        Get email preferences for the authenticated user

        Source file:
        `api-server/src/controllers/v2/users/get-email-preferences.controller.ts`
        """
        return self._get(
            "/v2/users/preferences/email",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailGetResponse,
        )


class AsyncEmailResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEmailResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEmailResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEmailResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncEmailResourceWithStreamingResponse(self)

    async def update(
        self,
        *,
        direct_notifications: bool | Omit = omit,
        relevant_activity: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailUpdateResponse:
        """
        Update email preferences for the authenticated user

        Source file:
        `api-server/src/controllers/v2/users/update-email-preferences.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._put(
            "/v2/users/preferences/email",
            body=await async_maybe_transform(
                {
                    "direct_notifications": direct_notifications,
                    "relevant_activity": relevant_activity,
                },
                email_update_params.EmailUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailUpdateResponse,
        )

    async def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmailGetResponse:
        """
        Get email preferences for the authenticated user

        Source file:
        `api-server/src/controllers/v2/users/get-email-preferences.controller.ts`
        """
        return await self._get(
            "/v2/users/preferences/email",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmailGetResponse,
        )


class EmailResourceWithRawResponse:
    def __init__(self, email: EmailResource) -> None:
        self._email = email

        self.update = to_raw_response_wrapper(
            email.update,
        )
        self.get = to_raw_response_wrapper(
            email.get,
        )


class AsyncEmailResourceWithRawResponse:
    def __init__(self, email: AsyncEmailResource) -> None:
        self._email = email

        self.update = async_to_raw_response_wrapper(
            email.update,
        )
        self.get = async_to_raw_response_wrapper(
            email.get,
        )


class EmailResourceWithStreamingResponse:
    def __init__(self, email: EmailResource) -> None:
        self._email = email

        self.update = to_streamed_response_wrapper(
            email.update,
        )
        self.get = to_streamed_response_wrapper(
            email.get,
        )


class AsyncEmailResourceWithStreamingResponse:
    def __init__(self, email: AsyncEmailResource) -> None:
        self._email = email

        self.update = async_to_streamed_response_wrapper(
            email.update,
        )
        self.get = async_to_streamed_response_wrapper(
            email.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .comment_edit_params import CommentEditParams as CommentEditParams
from .event_list_response import EventListResponse as EventListResponse
from .paper_vote_response import PaperVoteResponse as PaperVoteResponse
from .paper_unclaim_response import PaperUnclaimResponse as PaperUnclaimResponse
from .paper_add_author_params import PaperAddAuthorParams as PaperAddAuthorParams
from .paper_admin_vote_params import PaperAdminVoteParams as PaperAdminVoteParams
from .paper_add_author_response import PaperAddAuthorResponse as PaperAddAuthorResponse
from .paper_admin_vote_response import PaperAdminVoteResponse as PaperAdminVoteResponse
from .paper_email_author_params import PaperEmailAuthorParams as PaperEmailAuthorParams
from .paper_kickoff_ai_response import PaperKickoffAIResponse as PaperKickoffAIResponse
from .sitemap_list_users_params import SitemapListUsersParams as SitemapListUsersParams
from .paper_crx_pdf_hit_response import PaperCrxPdfHitResponse as PaperCrxPdfHitResponse
from .sitemap_list_papers_params import SitemapListPapersParams as SitemapListPapersParams
from .paper_email_author_response import PaperEmailAuthorResponse as PaperEmailAuthorResponse
from .search_closest_topic_params import SearchClosestTopicParams as SearchClosestTopicParams
from .search_google_search_params import SearchGoogleSearchParams as SearchGoogleSearchParams
from .sitemap_list_users_response import SitemapListUsersResponse as SitemapListUsersResponse
from .paper_crx_pdf_click_response import PaperCrxPdfClickResponse as PaperCrxPdfClickResponse
from .paper_toggle_follow_response import PaperToggleFollowResponse as PaperToggleFollowResponse
from .sitemap_list_papers_response import SitemapListPapersResponse as SitemapListPapersResponse
from .paper_get_paper_info_response import PaperGetPaperInfoResponse as PaperGetPaperInfoResponse
from .paper_kickoff_bibtex_response import PaperKickoffBibtexResponse as PaperKickoffBibtexResponse
from .paper_kickoff_github_response import PaperKickoffGitHubResponse as PaperKickoffGitHubResponse
from .paper_process_metadata_params import PaperProcessMetadataParams as PaperProcessMetadataParams
from .search_closest_topic_response import SearchClosestTopicResponse as SearchClosestTopicResponse
from .sitemap_list_overviews_params import SitemapListOverviewsParams as SitemapListOverviewsParams
from .user_get_private_notes_params import UserGetPrivateNotesParams as UserGetPrivateNotesParams
from .assistant_upload_file_response import AssistantUploadFileResponse as AssistantUploadFileResponse
from .paper_request_ai_latest_params import PaperRequestAILatestParams as PaperRequestAILatestParams
from .research_create_project_params import ResearchCreateProjectParams as ResearchCreateProjectParams
from .paper_crx_abstract_hit_response import PaperCrxAbstractHitResponse as PaperCrxAbstractHitResponse
from .paper_process_metadata_response import PaperProcessMetadataResponse as PaperProcessMetadataResponse
from .sitemap_list_overviews_response import SitemapListOverviewsResponse as SitemapListOverviewsResponse
from .user_get_private_notes_response import UserGetPrivateNotesResponse as UserGetPrivateNotesResponse
from .paper_request_ai_latest_response import PaperRequestAILatestResponse as PaperRequestAILatestResponse
from .research_create_project_response import ResearchCreateProjectResponse as ResearchCreateProjectResponse
from .paper_crx_abstract_click_response import PaperCrxAbstractClickResponse as PaperCrxAbstractClickResponse
from .paper_get_crx_paper_info_response import PaperGetCrxPaperInfoResponse as PaperGetCrxPaperInfoResponse
from .wrapped_retrieve_by_user_response import WrappedRetrieveByUserResponse as WrappedRetrieveByUserResponse
from .email_process_bounced_email_params import EmailProcessBouncedEmailParams as EmailProcessBouncedEmailParams
from .paper_set_github_repository_params import PaperSetGitHubRepositoryParams as PaperSetGitHubRepositoryParams
from .email_capture_bounced_emails_params import EmailCaptureBouncedEmailsParams as EmailCaptureBouncedEmailsParams
from .email_process_comment_update_params import EmailProcessCommentUpdateParams as EmailProcessCommentUpdateParams
from .email_process_general_update_params import EmailProcessGeneralUpdateParams as EmailProcessGeneralUpdateParams
from .paper_process_abstract_embed_params import PaperProcessAbstractEmbedParams as PaperProcessAbstractEmbedParams
from .email_process_bounced_email_response import EmailProcessBouncedEmailResponse as EmailProcessBouncedEmailResponse
from .paper_kickoff_recent_papers_response import PaperKickoffRecentPapersResponse as PaperKickoffRecentPapersResponse
from .paper_set_github_repository_response import PaperSetGitHubRepositoryResponse as PaperSetGitHubRepositoryResponse
from .paper_translate_ai_overview_response import PaperTranslateAIOverviewResponse as PaperTranslateAIOverviewResponse
from .email_capture_bounced_emails_response import (
    EmailCaptureBouncedEmailsResponse as EmailCaptureBouncedEmailsResponse,
)
from .email_kickoff_comment_update_response import (
    EmailKickoffCommentUpdateResponse as EmailKickoffCommentUpdateResponse,
)
from .email_kickoff_general_update_response import (
    EmailKickoffGeneralUpdateResponse as EmailKickoffGeneralUpdateResponse,
)
from .email_process_comment_update_response import (
    EmailProcessCommentUpdateResponse as EmailProcessCommentUpdateResponse,
)
from .email_process_general_update_response import (
    EmailProcessGeneralUpdateResponse as EmailProcessGeneralUpdateResponse,
)
from .paper_kickoff_abstract_embed_response import (
    PaperKickoffAbstractEmbedResponse as PaperKickoffAbstractEmbedResponse,
)
from .paper_process_abstract_embed_response import (
    PaperProcessAbstractEmbedResponse as PaperProcessAbstractEmbedResponse,
)
from .user_weigh_weekly_reputation_response import (
    UserWeighWeeklyReputationResponse as UserWeighWeeklyReputationResponse,
)
from .email_capture_resend_bounced_email_params import (
    EmailCaptureResendBouncedEmailParams as EmailCaptureResendBouncedEmailParams,
)
from .email_capture_resend_bounced_email_response import (
    EmailCaptureResendBouncedEmailResponse as EmailCaptureResendBouncedEmailResponse,
)
from .paper_kickoff_paper_categorization_response import (
    PaperKickoffPaperCategorizationResponse as PaperKickoffPaperCategorizationResponse,
)
from .paper_request_ai_translation_latest_response import (
    PaperRequestAITranslationLatestResponse as PaperRequestAITranslationLatestResponse,
)
from .notification_send_kickoff_notification_emails_response import (
    NotificationSendKickoffNotificationEmailsResponse as NotificationSendKickoffNotificationEmailsResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ....._models import BaseModel

__all__ = ["TopicListResponse", "Topic"]


class Topic(BaseModel):
    id: str

    topic: str


class TopicListResponse(BaseModel):
    topics: List[Topic]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["EmailUpdateParams"]


class EmailUpdateParams(TypedDict, total=False):
    direct_notifications: Annotated[bool, PropertyInfo(alias="directNotifications")]

    relevant_activity: Annotated[bool, PropertyInfo(alias="relevantActivity")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional

import httpx

from .v2.v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from ...types import comment_edit_params
from ..._types import Body, Query, Headers, NoneType, NotGiven, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["CommentsResource", "AsyncCommentsResource"]


class CommentsResource(SyncAPIResource):
    @cached_property
    def v2(self) -> V2Resource:
        return V2Resource(self._client)

    @cached_property
    def with_raw_response(self) -> CommentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return CommentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CommentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return CommentsResourceWithStreamingResponse(self)

    def edit(
        self,
        comment: str,
        *,
        anchor_position: Optional[comment_edit_params.AnchorPosition],
        body: str,
        focus_position: Optional[comment_edit_params.FocusPosition],
        highlight_color: Optional[str],
        highlight_rects: Optional[Iterable[comment_edit_params.HighlightRect]],
        selected_text: Optional[str],
        title: Optional[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Edit a comment by UUID

        Source file: `api-server/src/controllers/comments/v1/edit-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            f"/comments/v1/{comment}",
            body=maybe_transform(
                {
                    "anchor_position": anchor_position,
                    "body": body,
                    "focus_position": focus_position,
                    "highlight_color": highlight_color,
                    "highlight_rects": highlight_rects,
                    "selected_text": selected_text,
                    "title": title,
                },
                comment_edit_params.CommentEditParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncCommentsResource(AsyncAPIResource):
    @cached_property
    def v2(self) -> AsyncV2Resource:
        return AsyncV2Resource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncCommentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCommentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCommentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncCommentsResourceWithStreamingResponse(self)

    async def edit(
        self,
        comment: str,
        *,
        anchor_position: Optional[comment_edit_params.AnchorPosition],
        body: str,
        focus_position: Optional[comment_edit_params.FocusPosition],
        highlight_color: Optional[str],
        highlight_rects: Optional[Iterable[comment_edit_params.HighlightRect]],
        selected_text: Optional[str],
        title: Optional[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Edit a comment by UUID

        Source file: `api-server/src/controllers/comments/v1/edit-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            f"/comments/v1/{comment}",
            body=await async_maybe_transform(
                {
                    "anchor_position": anchor_position,
                    "body": body,
                    "focus_position": focus_position,
                    "highlight_color": highlight_color,
                    "highlight_rects": highlight_rects,
                    "selected_text": selected_text,
                    "title": title,
                },
                comment_edit_params.CommentEditParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class CommentsResourceWithRawResponse:
    def __init__(self, comments: CommentsResource) -> None:
        self._comments = comments

        self.edit = to_raw_response_wrapper(
            comments.edit,
        )

    @cached_property
    def v2(self) -> V2ResourceWithRawResponse:
        return V2ResourceWithRawResponse(self._comments.v2)


class AsyncCommentsResourceWithRawResponse:
    def __init__(self, comments: AsyncCommentsResource) -> None:
        self._comments = comments

        self.edit = async_to_raw_response_wrapper(
            comments.edit,
        )

    @cached_property
    def v2(self) -> AsyncV2ResourceWithRawResponse:
        return AsyncV2ResourceWithRawResponse(self._comments.v2)


class CommentsResourceWithStreamingResponse:
    def __init__(self, comments: CommentsResource) -> None:
        self._comments = comments

        self.edit = to_streamed_response_wrapper(
            comments.edit,
        )

    @cached_property
    def v2(self) -> V2ResourceWithStreamingResponse:
        return V2ResourceWithStreamingResponse(self._comments.v2)


class AsyncCommentsResourceWithStreamingResponse:
    def __init__(self, comments: AsyncCommentsResource) -> None:
        self._comments = comments

        self.edit = async_to_streamed_response_wrapper(
            comments.edit,
        )

    @cached_property
    def v2(self) -> AsyncV2ResourceWithStreamingResponse:
        return AsyncV2ResourceWithStreamingResponse(self._comments.v2)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from .._models import BaseModel

__all__ = ["WrappedRetrieveByUserResponse", "WrappedRetrieveByUserResponseItem"]


class WrappedRetrieveByUserResponseItem(BaseModel):
    id: str

    order: float

    type: str

    year: float

    data: Optional[object] = None


WrappedRetrieveByUserResponse: TypeAlias = List[WrappedRetrieveByUserResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "V3RetrieveSimilarPapersResponse",
    "V3RetrieveSimilarPapersResponseItem",
    "V3RetrieveSimilarPapersResponseItemAuthorInfo",
    "V3RetrieveSimilarPapersResponseItemAuthorInfoAvatar",
    "V3RetrieveSimilarPapersResponseItemFullAuthor",
    "V3RetrieveSimilarPapersResponseItemMetrics",
    "V3RetrieveSimilarPapersResponseItemMetricsVisitsCount",
    "V3RetrieveSimilarPapersResponseItemOrganizationInfo",
    "V3RetrieveSimilarPapersResponseItemPaperSummary",
]


class V3RetrieveSimilarPapersResponseItemAuthorInfoAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class V3RetrieveSimilarPapersResponseItemAuthorInfo(BaseModel):
    id: str

    avatar: Optional[List[V3RetrieveSimilarPapersResponseItemAuthorInfoAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class V3RetrieveSimilarPapersResponseItemFullAuthor(BaseModel):
    id: str

    full_name: str

    user_id: Optional[str] = None

    username: Optional[str] = None


class V3RetrieveSimilarPapersResponseItemMetricsVisitsCount(BaseModel):
    all: float

    last_7_days: float


class V3RetrieveSimilarPapersResponseItemMetrics(BaseModel):
    public_total_votes: float

    total_votes: float

    visits_count: V3RetrieveSimilarPapersResponseItemMetricsVisitsCount

    x_likes: float


class V3RetrieveSimilarPapersResponseItemOrganizationInfo(BaseModel):
    image: Optional[str] = None

    name: str


class V3RetrieveSimilarPapersResponseItemPaperSummary(BaseModel):
    key_insights: List[str] = FieldInfo(alias="keyInsights")

    original_problem: List[str] = FieldInfo(alias="originalProblem")

    results: List[str]

    solution: List[str]

    summary: str


class V3RetrieveSimilarPapersResponseItem(BaseModel):
    id: str

    abstract: str

    author_info: List[V3RetrieveSimilarPapersResponseItemAuthorInfo]

    authors: List[str]

    canonical_id: str
    """A versioned paper ID (e.g. 1706.03762v1)"""

    first_publication_date: str

    full_authors: List[V3RetrieveSimilarPapersResponseItemFullAuthor]

    github_stars: Optional[float] = None

    github_url: Optional[str] = None

    image_url: Optional[str] = None

    metrics: V3RetrieveSimilarPapersResponseItemMetrics

    organization_info: List[V3RetrieveSimilarPapersResponseItemOrganizationInfo]

    paper_group_id: str

    paper_summary: Optional[V3RetrieveSimilarPapersResponseItemPaperSummary] = None

    publication_date: str

    title: str

    topics: List[str]

    universal_paper_id: str
    """A versionless universal paper ID (e.g. 1706.03762)"""

    updated_at: str

    version_id: str


V3RetrieveSimilarPapersResponse: TypeAlias = List[V3RetrieveSimilarPapersResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import Body, Query, Headers, NotGiven, not_given
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.wrapped_retrieve_by_user_response import WrappedRetrieveByUserResponse

__all__ = ["WrappedResource", "AsyncWrappedResource"]


class WrappedResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> WrappedResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return WrappedResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> WrappedResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return WrappedResourceWithStreamingResponse(self)

    def retrieve_by_user(
        self,
        user_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> WrappedRetrieveByUserResponse:
        """
        Get all wrapped data for a specific user across all years

        Source file:
        `api-server/src/controllers/wrapped/v1/get-wrapped-by-user.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return self._get(
            f"/wrapped/v1/{user_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WrappedRetrieveByUserResponse,
        )


class AsyncWrappedResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncWrappedResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncWrappedResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncWrappedResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncWrappedResourceWithStreamingResponse(self)

    async def retrieve_by_user(
        self,
        user_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> WrappedRetrieveByUserResponse:
        """
        Get all wrapped data for a specific user across all years

        Source file:
        `api-server/src/controllers/wrapped/v1/get-wrapped-by-user.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not user_id:
            raise ValueError(f"Expected a non-empty value for `user_id` but received {user_id!r}")
        return await self._get(
            f"/wrapped/v1/{user_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=WrappedRetrieveByUserResponse,
        )


class WrappedResourceWithRawResponse:
    def __init__(self, wrapped: WrappedResource) -> None:
        self._wrapped = wrapped

        self.retrieve_by_user = to_raw_response_wrapper(
            wrapped.retrieve_by_user,
        )


class AsyncWrappedResourceWithRawResponse:
    def __init__(self, wrapped: AsyncWrappedResource) -> None:
        self._wrapped = wrapped

        self.retrieve_by_user = async_to_raw_response_wrapper(
            wrapped.retrieve_by_user,
        )


class WrappedResourceWithStreamingResponse:
    def __init__(self, wrapped: WrappedResource) -> None:
        self._wrapped = wrapped

        self.retrieve_by_user = to_streamed_response_wrapper(
            wrapped.retrieve_by_user,
        )


class AsyncWrappedResourceWithStreamingResponse:
    def __init__(self, wrapped: AsyncWrappedResource) -> None:
        self._wrapped = wrapped

        self.retrieve_by_user = async_to_streamed_response_wrapper(
            wrapped.retrieve_by_user,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["V1GenerateSpeechResponse"]


class V1GenerateSpeechResponse(BaseModel):
    url: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from .v3 import (
    V3Resource,
    AsyncV3Resource,
    V3ResourceWithRawResponse,
    AsyncV3ResourceWithRawResponse,
    V3ResourceWithStreamingResponse,
    AsyncV3ResourceWithStreamingResponse,
)
from .ingest import (
    IngestResource,
    AsyncIngestResource,
    IngestResourceWithRawResponse,
    AsyncIngestResourceWithRawResponse,
    IngestResourceWithStreamingResponse,
    AsyncIngestResourceWithStreamingResponse,
)
from .papers import (
    PapersResource,
    AsyncPapersResource,
    PapersResourceWithRawResponse,
    AsyncPapersResourceWithRawResponse,
    PapersResourceWithStreamingResponse,
    AsyncPapersResourceWithStreamingResponse,
)
from .private import (
    PrivateResource,
    AsyncPrivateResource,
    PrivateResourceWithRawResponse,
    AsyncPrivateResourceWithRawResponse,
    PrivateResourceWithStreamingResponse,
    AsyncPrivateResourceWithStreamingResponse,
)
from .metadata import (
    MetadataResource,
    AsyncMetadataResource,
    MetadataResourceWithRawResponse,
    AsyncMetadataResourceWithRawResponse,
    MetadataResourceWithStreamingResponse,
    AsyncMetadataResourceWithStreamingResponse,
)
from .versions import (
    VersionsResource,
    AsyncVersionsResource,
    VersionsResourceWithRawResponse,
    AsyncVersionsResourceWithRawResponse,
    VersionsResourceWithStreamingResponse,
    AsyncVersionsResourceWithStreamingResponse,
)
from .kickoff_daily_github_stars import (
    KickoffDailyGitHubStarsResource,
    AsyncKickoffDailyGitHubStarsResource,
    KickoffDailyGitHubStarsResourceWithRawResponse,
    AsyncKickoffDailyGitHubStarsResourceWithRawResponse,
    KickoffDailyGitHubStarsResourceWithStreamingResponse,
    AsyncKickoffDailyGitHubStarsResourceWithStreamingResponse,
)

__all__ = [
    "VersionsResource",
    "AsyncVersionsResource",
    "VersionsResourceWithRawResponse",
    "AsyncVersionsResourceWithRawResponse",
    "VersionsResourceWithStreamingResponse",
    "AsyncVersionsResourceWithStreamingResponse",
    "MetadataResource",
    "AsyncMetadataResource",
    "MetadataResourceWithRawResponse",
    "AsyncMetadataResourceWithRawResponse",
    "MetadataResourceWithStreamingResponse",
    "AsyncMetadataResourceWithStreamingResponse",
    "IngestResource",
    "AsyncIngestResource",
    "IngestResourceWithRawResponse",
    "AsyncIngestResourceWithRawResponse",
    "IngestResourceWithStreamingResponse",
    "AsyncIngestResourceWithStreamingResponse",
    "PrivateResource",
    "AsyncPrivateResource",
    "PrivateResourceWithRawResponse",
    "AsyncPrivateResourceWithRawResponse",
    "PrivateResourceWithStreamingResponse",
    "AsyncPrivateResourceWithStreamingResponse",
    "KickoffDailyGitHubStarsResource",
    "AsyncKickoffDailyGitHubStarsResource",
    "KickoffDailyGitHubStarsResourceWithRawResponse",
    "AsyncKickoffDailyGitHubStarsResourceWithRawResponse",
    "KickoffDailyGitHubStarsResourceWithStreamingResponse",
    "AsyncKickoffDailyGitHubStarsResourceWithStreamingResponse",
    "V3Resource",
    "AsyncV3Resource",
    "V3ResourceWithRawResponse",
    "AsyncV3ResourceWithRawResponse",
    "V3ResourceWithStreamingResponse",
    "AsyncV3ResourceWithStreamingResponse",
    "V2Resource",
    "AsyncV2Resource",
    "V2ResourceWithRawResponse",
    "AsyncV2ResourceWithRawResponse",
    "V2ResourceWithStreamingResponse",
    "AsyncV2ResourceWithStreamingResponse",
    "PapersResource",
    "AsyncPapersResource",
    "PapersResourceWithRawResponse",
    "AsyncPapersResourceWithRawResponse",
    "PapersResourceWithStreamingResponse",
    "AsyncPapersResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .api_keys import (
    APIKeysResource,
    AsyncAPIKeysResource,
    APIKeysResourceWithRawResponse,
    AsyncAPIKeysResourceWithRawResponse,
    APIKeysResourceWithStreamingResponse,
    AsyncAPIKeysResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "APIKeysResource",
    "AsyncAPIKeysResource",
    "APIKeysResourceWithRawResponse",
    "AsyncAPIKeysResourceWithRawResponse",
    "APIKeysResourceWithStreamingResponse",
    "AsyncAPIKeysResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["PaperVoteResponse", "Data", "DataPaperGroup"]


class DataPaperGroup(BaseModel):
    api_id: str = FieldInfo(alias="_id")


class Data(BaseModel):
    paper_group: DataPaperGroup = FieldInfo(alias="paperGroup")


class PaperVoteResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_generate_speech_params import V1GenerateSpeechParams as V1GenerateSpeechParams
from .v1_generate_speech_response import V1GenerateSpeechResponse as V1GenerateSpeechResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3RetrieveFeedParams"]


class V3RetrieveFeedParams(TypedDict, total=False):
    interval: Required[Literal["3 Days", "7 Days", "30 Days", "90 Days", "All time"]]

    page_num: Required[Annotated[str, PropertyInfo(alias="pageNum")]]

    page_size: Required[Annotated[str, PropertyInfo(alias="pageSize")]]

    sort: Required[Literal["Hot", "Comments", "Views", "Likes", "GitHub", "Twitter (X)", "Recommended"]]

    exclude_seen_briefs: Annotated[Literal["true", "false"], PropertyInfo(alias="excludeSeenBriefs")]

    organizations: str

    require_summary: Annotated[Literal["true", "false"], PropertyInfo(alias="requireSummary")]

    source: Literal["GitHub", "Twitter (X)"]

    topics: str

    universal_id: Annotated[str, PropertyInfo(alias="universalId")]
    """A versionless universal paper ID (e.g. 1706.03762)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3UpdateProfileParams"]


class V3UpdateProfileParams(TypedDict, total=False):
    biography: Optional[str]

    bluesky_username: Annotated[Optional[str], PropertyInfo(alias="blueskyUsername")]

    github_username: Annotated[Optional[str], PropertyInfo(alias="githubUsername")]

    institution: Optional[str]

    linkedin_username: Annotated[Optional[str], PropertyInfo(alias="linkedinUsername")]

    location: Optional[str]

    public_email: Annotated[Optional[str], PropertyInfo(alias="publicEmail")]

    real_name: Annotated[str, PropertyInfo(alias="realName")]

    username: str

    x_username: Annotated[Optional[str], PropertyInfo(alias="xUsername")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from .moderator import (
    ModeratorResource,
    AsyncModeratorResource,
    ModeratorResourceWithRawResponse,
    AsyncModeratorResourceWithRawResponse,
    ModeratorResourceWithStreamingResponse,
    AsyncModeratorResourceWithStreamingResponse,
)

__all__ = [
    "ModeratorResource",
    "AsyncModeratorResource",
    "ModeratorResourceWithRawResponse",
    "AsyncModeratorResourceWithRawResponse",
    "ModeratorResourceWithStreamingResponse",
    "AsyncModeratorResourceWithStreamingResponse",
    "V2Resource",
    "AsyncV2Resource",
    "V2ResourceWithRawResponse",
    "AsyncV2ResourceWithRawResponse",
    "V2ResourceWithStreamingResponse",
    "AsyncV2ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

from ..._types import SequenceNotStr

__all__ = ["V3DeleteVotesParams"]


class V3DeleteVotesParams(TypedDict, total=False):
    body: SequenceNotStr[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3ToggleSharingResponse"]


class V3ToggleSharingResponse(BaseModel):
    sharing_status: Literal["not_shared", "shared"] = FieldInfo(alias="sharingStatus")
